/*-
 * ============LICENSE_START=======================================================
 *  Copyright (C) 2021 Nordix Foundation.
 * ================================================================================
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * SPDX-License-Identifier: Apache-2.0
 * ============LICENSE_END=========================================================
 */

package org.onap.policy.clamp.controlloop.participant.intermediary.api;

import java.util.UUID;
import org.onap.policy.clamp.controlloop.models.controlloop.concepts.ControlLoopElement;
import org.onap.policy.clamp.controlloop.models.controlloop.concepts.ControlLoopOrderedState;
import org.onap.policy.clamp.controlloop.models.controlloop.concepts.ControlLoopState;
import org.onap.policy.models.base.PfModelException;
import org.onap.policy.models.tosca.authorative.concepts.ToscaNodeTemplate;

/**
 * This interface is implemented by participant implementations to receive updates on control loop elements.
 */
public interface ControlLoopElementListener {
    /**
     * Handle a control loop element state change.
     *
     * @param controlLoopElementId the ID of the control loop element
     * @param currentState the current state of the control loop element
     * @param newState the state to which the control loop element is changing to
     * @throws PfModelException in case of a model exception
     */
    public void controlLoopElementStateChange(UUID controlLoopElementId, ControlLoopState currentState,
            ControlLoopOrderedState newState) throws PfModelException;

    /**
     * Handle an update on a control loop element.
     *
     * @param element the information on the control loop element
     * @param controlLoopElementDefinition toscaNodeTemplate
     * @throws PfModelException from Policy framework
     */
    public void controlLoopElementUpdate(ControlLoopElement element,
            ToscaNodeTemplate controlLoopElementDefinition) throws PfModelException;

    /**
     * Handle controlLoopElement statistics.
     *
     * @param controlLoopElementId controlLoopElement id
     * @throws PfModelException in case of a model exception
     */
    public void handleStatistics(UUID controlLoopElementId) throws PfModelException;
}
